Module tensorboard_proto::plugin_hparams
source · [−]Expand description
Generated file from src/plugin_hparams.proto
Structs
Generated files are compatible only with the same version of protobuf runtime.
Generated file from src/plugin_hparams.proto
Generated files are compatible only with the same version of protobuf runtime.