Module tensorboard_proto::plugin_text
source · [−]Expand description
Generated file from src/plugin_text.proto
Structs
Generated files are compatible only with the same version of protobuf runtime.
Generated file from src/plugin_text.proto
Generated files are compatible only with the same version of protobuf runtime.