Module tensorboard_proto::plugin_mesh
source · [−]Expand description
Generated file from src/tensorboardrs/proto/plugin_mesh.proto
Structs
Generated files are compatible only with the same version of protobuf runtime.
Generated file from src/tensorboardrs/proto/plugin_mesh.proto
Generated files are compatible only with the same version of protobuf runtime.